@@ -167,8 +167,7 @@ class RootTerminalBox(Gtk.Overlay, TerminalHolder):
 
     def iter_terminals(self):
         if self.get_child() is not None:
-            for t in self.get_child().iter_terminals():
-                yield t
+            yield from self.get_child().iter_terminals()
 
     def replace_child(self, old, new):
         self.remove(old)
@@ -221,17 +220,14 @@ class RootTerminalBox(Gtk.Overlay, TerminalHolder):
 
     def restore_box_layout(self, box, panes: list):
         """Restore box layout by `panes`"""
-        if not panes or not isinstance(panes, list):
-            return
-        if not box or not isinstance(box, TerminalBox):
-            # Should only called on TerminalBox
+        if not panes or not isinstance(panes, list) or not box or not isinstance(box, TerminalBox):
             return
 
         cur = panes.pop(0)
         if cur["type"].startswith("dual"):
             while True:
                 if self.guake:
-                    # If Guake are not visible, we should pending the restore, then do the
+                    # If Guake is not visible, we should pending the restore, then do the
                     # restore when Guake is visible again.
                     #
                     # Otherwise we will stuck in the infinite loop, since new DualTerminalBox
@@ -257,9 +253,9 @@ class RootTerminalBox(Gtk.Overlay, TerminalHolder):
                     Gtk.main_iteration()
 
             if cur["type"].endswith("v"):
-                box = box.split_v()
+                box = box.split_v_no_save()
             else:
-                box = box.split_h()
+                box = box.split_h_no_save()
             self.restore_box_layout(box.get_child1(), panes)
             self.restore_box_layout(box.get_child2(), panes)
         else:
@@ -384,7 +380,6 @@ class RootTerminalBox(Gtk.Overlay, TerminalHolder):
 
 
 class TerminalBox(Gtk.Box, TerminalHolder):
-
     """A box to group the terminal and a scrollbar."""
 
     def __init__(self):
@@ -412,7 +407,7 @@ class TerminalBox(Gtk.Box, TerminalHolder):
     def add_scroll_bar(self):
         """Packs the scrollbar."""
         adj = self.terminal.get_vadjustment()
-        self.scroll = Gtk.VScrollbar(adj)
+        self.scroll = Gtk.Scrollbar.new(Gtk.Orientation.VERTICAL, adj)
         self.scroll.show()
         self.pack_start(self.scroll, False, False, 0)
 
@@ -456,20 +451,30 @@ class TerminalBox(Gtk.Box, TerminalHolder):
     def unset_terminal(self, *args):
         self.terminal = None
 
-    def split_h(self):
-        return self.split(DualTerminalBox.ORIENT_V)
+    def split_h(self, split_percentage: int = 50):
+        return self.split(DualTerminalBox.ORIENT_V, split_percentage)
 
-    def split_v(self):
-        return self.split(DualTerminalBox.ORIENT_H)
+    def split_v(self, split_percentage: int = 50):
+        return self.split(DualTerminalBox.ORIENT_H, split_percentage)
 
-    def split(self, orientation):
+    def split_h_no_save(self, split_percentage: int = 50):
+        return self.split_no_save(DualTerminalBox.ORIENT_V, split_percentage)
+
+    def split_v_no_save(self, split_percentage: int = 50):
+        return self.split_no_save(DualTerminalBox.ORIENT_H, split_percentage)
+
+    @save_tabs_when_changed
+    def split(self, orientation, split_percentage: int = 50):
+        self.split_no_save(orientation, split_percentage)
+
+    def split_no_save(self, orientation, split_percentage: int = 50):
         notebook = self.get_notebook()
         parent = self.get_parent()  # RootTerminalBox
 
         if orientation == DualTerminalBox.ORIENT_H:
-            position = self.get_allocation().width / 2
+            position = self.get_allocation().width * ((100 - split_percentage) / 100)
         else:
-            position = self.get_allocation().height / 2
+            position = self.get_allocation().height * ((100 - split_percentage) / 100)
 
         terminal_box = TerminalBox()
         terminal = notebook.terminal_spawn()
@@ -481,6 +486,10 @@ class TerminalBox(Gtk.Box, TerminalHolder):
         dual_terminal_box.set_child_second(terminal_box)
         terminal_box.show()
         dual_terminal_box.show()
+        if self.terminal is not None:
+            # preserve font and font_scale in the new terminal
+            terminal.set_font(self.terminal.font)
+            terminal.font_scale = self.terminal.font_scale
         notebook.terminal_attached(terminal)
 
         return dual_terminal_box
@@ -574,10 +583,8 @@ class DualTerminalBox(Gtk.Paned, TerminalHolder):
         return self.get_child1().get_terminals() + self.get_child2().get_terminals()
 
     def iter_terminals(self):
-        for t in self.get_child1().iter_terminals():
-            yield t
-        for t in self.get_child2().iter_terminals():
-            yield t
+        yield from self.get_child1().iter_terminals()
+        yield from self.get_child2().iter_terminals()
 
     def replace_child(self, old, new):
         if self.get_child1() is old:
@@ -613,6 +620,7 @@ class DualTerminalBox(Gtk.Paned, TerminalHolder):
         else:
             box.get_terminal().grab_focus()
 
+    @save_tabs_when_changed
     def remove_dead_child(self, child):
         if self.get_child1() is child:
             living_child = self.get_child2()
@@ -632,8 +640,8 @@ class TabLabelEventBox(Gtk.EventBox):
     def __init__(self, notebook, text, settings):
         super().__init__()
         self.notebook = notebook
-        self.box = Gtk.Box(Gtk.Orientation.HORIZONTAL, 0, visible=True)
-        self.label = Gtk.Label(text, visible=True)
+        self.box = Gtk.Box(homogeneous=Gtk.Orientation.HORIZONTAL, spacing=0, visible=True)
+        self.label = Gtk.Label(label=text, visible=True)
         self.close_button = Gtk.Button(
             image=Gtk.Image.new_from_icon_name("window-close", Gtk.IconSize.MENU),
             relief=Gtk.ReliefStyle.NONE,
