@@ -24,8 +24,8 @@ from collections import defaultdict
 import gi
 
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gtk
 
 from guake import notifier
 from guake.common import pixmapfile
@@ -36,7 +36,6 @@ log = logging.getLogger(__name__)
 
 
 class Keybindings:
-
     """Handles changes in keyboard shortcuts."""
 
     def __init__(self, guake):
@@ -67,6 +66,7 @@ class Keybindings:
             ("toggle-fullscreen", self.guake.accel_toggle_fullscreen),
             ("new-tab", self.guake.accel_add),
             ("new-tab-home", self.guake.accel_add_home),
+            ("new-tab-cwd", self.guake.accel_add_cwd),
             ("close-tab", x),
             ("rename-current-tab", self.guake.accel_rename_current_tab),
             ("previous-tab", self.guake.accel_prev),
@@ -75,6 +75,7 @@ class Keybindings:
             ("next-tab-alt", self.guake.accel_next),
             ("clipboard-copy", self.guake.accel_copy_clipboard),
             ("clipboard-paste", self.guake.accel_paste_clipboard),
+            ("select-all", self.guake.accel_select_all),
             ("quit", self.guake.accel_quit),
             ("zoom-in", self.guake.accel_zoom_in),
             ("zoom-in-alt", self.guake.accel_zoom_in),
@@ -197,7 +198,7 @@ class Keybindings:
         ]
         for key, _ in self.keys:
             guake.settings.keybindingsLocal.onChangedValue(key, self.reload_accelerators)
-            self.reload_accelerators()
+        self.reload_accelerators()
 
     def reload_global(self, settings, key, user_data):
         value = settings.get_string(key)
@@ -274,7 +275,7 @@ class Keybindings:
         self.guake.accel_group = self
 
     def load_accelerators(self):
-        """Reads all gconf paths under /apps/guake/keybindings/local
+        """Reads all gconf paths under /org/guake/keybindings/local
         and adds to the _lookup.
         """
 
