@@ -37,7 +37,7 @@ from locale import gettext
 
 builtins.__dict__["_"] = gettext
 
-from optparse import OptionParser
+from argparse import ArgumentParser
 
 log = logging.getLogger(__name__)
 
@@ -75,10 +75,17 @@ def main():
     """
     # Force to xterm-256 colors for compatibility with some old command line programs
     os.environ["TERM"] = "xterm-256color"
+    os.environ["TERM_PROGRAM"] = "guake"
 
     # do not use version keywords here, pbr might be slow to find the version of Guake module
-    parser = OptionParser()
-    parser.add_option(
+    parser = ArgumentParser()
+    parser.add_argument(
+        "path",
+        nargs="?",
+        help="Add a new tab at designated path when a path is provided and no other options",
+    )
+
+    parser.add_argument(
         "-V",
         "--version",
         dest="version",
@@ -87,7 +94,7 @@ def main():
         help=_("Show Guake version number and exit"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-v",
         "--verbose",
         dest="verbose",
@@ -96,7 +103,7 @@ def main():
         help=_("Enable verbose logging"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-f",
         "--fullscreen",
         dest="fullscreen",
@@ -105,7 +112,7 @@ def main():
         help=_("Put Guake in fullscreen mode"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--unfullscreen",
         dest="unfullscreen",
         action="store_true",
@@ -113,7 +120,7 @@ def main():
         help=_("Put Guake out from fullscreen mode"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-t",
         "--toggle-visibility",
         dest="show_hide",
@@ -122,7 +129,7 @@ def main():
         help=_("Toggles the visibility of the terminal window"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--is-visible",
         dest="is_visible",
         action="store_true",
@@ -130,7 +137,7 @@ def main():
         help=_("Return 1 if Guake is visible, 0 otherwise"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--show",
         dest="show",
         action="store_true",
@@ -138,7 +145,7 @@ def main():
         help=_("Shows Guake main window"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--hide",
         dest="hide",
         action="store_true",
@@ -146,7 +153,7 @@ def main():
         help=_("Hides Guake main window"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-p",
         "--preferences",
         dest="show_preferences",
@@ -155,7 +162,7 @@ def main():
         help=_("Shows Guake preference window"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-a",
         "--about",
         dest="show_about",
@@ -164,7 +171,7 @@ def main():
         help=_("Shows Guake's about info"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-n",
         "--new-tab",
         dest="new_tab",
@@ -173,7 +180,7 @@ def main():
         help=_("Add a new tab (with current directory set to NEW_TAB)"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-s",
         "--select-tab",
         dest="select_tab",
@@ -182,7 +189,7 @@ def main():
         help=_("Select a tab (SELECT_TAB is the index of the tab)"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-g",
         "--selected-tab",
         dest="selected_tab",
@@ -191,7 +198,16 @@ def main():
         help=_("Return the selected tab index."),
     )
 
-    parser.add_option(
+    parser.add_argument(
+        "-x",
+        "--uuid-index",
+        dest="uuid_index",
+        action="store",
+        default="",
+        help=_("Return the index of the tab with the given terminal UUID, -1 if not found"),
+    )
+
+    parser.add_argument(
         "-l",
         "--selected-tablabel",
         dest="selected_tablabel",
@@ -200,7 +216,7 @@ def main():
         help=_("Return the selected tab label."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-S",
         "--select-terminal",
         dest="select_terminal",
@@ -213,7 +229,7 @@ def main():
         ),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--selected-terminal",
         dest="selected_terminal",
         action="store_true",
@@ -221,32 +237,44 @@ def main():
         help=_("Return the selected terminal index."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--split-vertical",
         dest="split_vertical",
-        action="store_true",
-        default=False,
-        help=_("Split the selected tab vertically."),
+        metavar="SPLIT_PERCENTAGE",
+        action="store",
+        type=int,
+        nargs="?",
+        const=50,
+        default=None,
+        choices=range(1, 100),
+        help=_("Split the selected tab vertically. Optional input split percentage for the width."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--split-horizontal",
         dest="split_horizontal",
-        action="store_true",
-        default=False,
-        help=_("Split the selected tab horizontally."),
+        metavar="SPLIT_PERCENTAGE",
+        action="store",
+        type=int,
+        nargs="?",
+        const=50,
+        default=None,
+        choices=range(1, 100),
+        help=_(
+            "Split the selected tab horizontally. Optional input split percentage for the height."
+        ),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-e",
         "--execute-command",
         dest="command",
         action="store",
         default="",
-        help=_("Execute an arbitrary command in the selected tab."),
+        help=_("Execute an arbitrary command in a new tab."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-i",
         "--tab-index",
         dest="tab_index",
@@ -255,39 +283,39 @@ def main():
         help=_("Specify the tab to rename. Default is 0. Can be used to select tab by UUID."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--bgcolor",
         dest="bgcolor",
         action="store",
         default="",
-        help=_("Set the hexadecimal (#rrggbb) background color of " "the selected tab."),
+        help=_("Set the hexadecimal (#rrggbb) background color of the selected tab."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--fgcolor",
         dest="fgcolor",
         action="store",
         default="",
-        help=_("Set the hexadecimal (#rrggbb) foreground color of the " "selected tab."),
+        help=_("Set the hexadecimal (#rrggbb) foreground color of the selected tab."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--bgcolor-current",
         dest="bgcolor_current",
         action="store",
         default="",
-        help=_("Set the hexadecimal (#rrggbb) background color of " "the current terminal."),
+        help=_("Set the hexadecimal (#rrggbb) background color of the current terminal."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--fgcolor-current",
         dest="fgcolor_current",
         action="store",
         default="",
-        help=_("Set the hexadecimal (#rrggbb) foreground color of " "the current terminal."),
+        help=_("Set the hexadecimal (#rrggbb) foreground color of the current terminal."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--change-palette",
         dest="palette_name",
         action="store",
@@ -295,7 +323,7 @@ def main():
         help=_("Change Guake palette scheme"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--reset-colors",
         dest="reset_colors",
         action="store_true",
@@ -303,7 +331,7 @@ def main():
         help=_("Set colors from settings."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--reset-colors-current",
         dest="reset_colors_current",
         action="store_true",
@@ -311,29 +339,28 @@ def main():
         help=_("Set colors of the current terminal from settings."),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--rename-tab",
         dest="rename_tab",
         metavar="TITLE",
         action="store",
         default="",
         help=_(
-            "Rename the specified tab by --tab-index. Reset to default if TITLE is "
-            'a single dash "-".'
+            'Rename tab specified by --tab-index. Reset to default if TITLE is a single dash "-".'
         ),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-r",
         "--rename-current-tab",
         dest="rename_current_tab",
         metavar="TITLE",
         action="store",
         default="",
-        help=_("Rename the current tab. Reset to default if TITLE is a " 'single dash "-".'),
+        help=_('Rename the current tab. Reset to default if TITLE is a single dash "-".'),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-q",
         "--quit",
         dest="quit",
@@ -342,7 +369,7 @@ def main():
         help=_("Says to Guake go away =("),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "-u",
         "--no-startup-script",
         dest="execute_startup_script",
@@ -351,7 +378,7 @@ def main():
         help=_("Do not execute the start up script"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--save-preferences",
         dest="save_preferences",
         action="store",
@@ -359,7 +386,7 @@ def main():
         help=_("Save Guake preferences to this filename"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--restore-preferences",
         dest="restore_preferences",
         action="store",
@@ -367,7 +394,7 @@ def main():
         help=_("Restore Guake preferences from this file"),
     )
 
-    parser.add_option(
+    parser.add_argument(
         "--support",
         dest="support",
         action="store_true",
@@ -420,7 +447,7 @@ def main():
         )
         sys.exit(1)
 
-    options = parser.parse_args()[0]
+    options = parser.parse_args()
     if options.version:
         from guake import gtk_version
         from guake import guake_version
@@ -503,10 +530,14 @@ def main():
         remote_object.show_prefs()
         only_show_hide = options.show
 
-    if options.new_tab:
+    if options.new_tab and not options.command:
         remote_object.add_tab(options.new_tab)
         only_show_hide = options.show
 
+    if options.path and len(sys.argv) == 2:
+        remote_object.add_tab(os.path.abspath(options.path))
+        only_show_hide = options.show
+
     if options.select_tab:
         selected = int(options.select_tab)
         tab_count = int(remote_object.get_tab_count())
@@ -526,12 +557,27 @@ def main():
         sys.stdout.write(f"{selectedlabel}\n")
         only_show_hide = options.show
 
+    if options.uuid_index:
+        selectedIndex = remote_object.get_index_from_uuid(options.uuid_index)
+        sys.stdout.write(f"{selectedIndex}\n")
+        only_show_hide = options.show
+
     if options.split_vertical:
-        remote_object.v_split_current_terminal()
+        if options.command:
+            remote_object.v_split_current_terminal_with_command(
+                options.command, options.split_vertical
+            )
+        else:
+            remote_object.v_split_current_terminal(options.split_vertical)
         only_show_hide = options.show
 
     if options.split_horizontal:
-        remote_object.h_split_current_terminal()
+        if options.command:
+            remote_object.h_split_current_terminal_with_command(
+                options.command, options.split_horizontal
+            )
+        else:
+            remote_object.h_split_current_terminal(options.split_horizontal)
         only_show_hide = options.show
 
     if options.selected_terminal:
@@ -548,7 +594,7 @@ def main():
             sys.stderr.write(f"invalid index: {selected}\n")
         only_show_hide = options.show
 
-    if options.command:
+    if options.command and not (options.split_vertical or options.split_horizontal):
         remote_object.execute_command(options.command)
         only_show_hide = options.show
 
@@ -612,15 +658,15 @@ def main():
             startup_script = instance.settings.general.get_string("startup-script")
             if startup_script:
                 log.info("Calling startup script: %s", startup_script)
-                with subprocess.Popen(
+                pid = subprocess.Popen(  # pylint: disable=consider-using-with
                     [startup_script],
-                    shell=True,
+                    shell=False,
                     stdin=None,
                     stdout=None,
                     stderr=None,
                     close_fds=True,
-                ) as pid:
-                    log.info("Startup script started with pid: %s", pid)
+                )
+                log.info("Startup script started with pid: %s", pid)
                 # Please ensure this is the last line !!!!
     else:
         log.info("--no-startup-script argument defined, so don't execute the startup script")
