@@ -25,9 +25,13 @@ from guake.boxes import TerminalBox
 from guake.callbacks import MenuHideCallback
 from guake.callbacks import NotebookScrollCallback
 from guake.dialogs import PromptQuitDialog
+from guake.globals import PROMPT_ALWAYS
+from guake.globals import PROMPT_PROCESSES
 from guake.menus import mk_notebook_context_menu
 from guake.prefs import PrefsDialog
+from guake.utils import HidePrevention
 from guake.utils import gdk_is_x11_display
+from guake.utils import get_process_name
 from guake.utils import save_tabs_when_changed
 
 import gi
@@ -68,14 +72,14 @@ class TerminalNotebook(Gtk.Notebook):
             GObject.signal_new(
                 "terminal-spawned",
                 TerminalNotebook,
-                GObject.SIGNAL_RUN_LAST,
+                GObject.SignalFlags.RUN_LAST,
                 GObject.TYPE_NONE,
                 (GObject.TYPE_PYOBJECT, GObject.TYPE_INT),
             )
             GObject.signal_new(
                 "page-deleted",
                 TerminalNotebook,
-                GObject.SIGNAL_RUN_LAST,
+                GObject.SignalFlags.RUN_LAST,
                 GObject.TYPE_NONE,
                 (),
             )
@@ -88,6 +92,11 @@ class TerminalNotebook(Gtk.Notebook):
         )
 
         # Action box
+        self.pin_button = Gtk.ToggleButton(
+            image=Gtk.Image.new_from_icon_name("view-pin-symbolic", Gtk.IconSize.MENU),
+            visible=False,
+        )
+        self.pin_button.connect("clicked", self.on_pin_clicked)
         self.new_page_button = Gtk.Button(
             image=Gtk.Image.new_from_icon_name("tab-new-symbolic", Gtk.IconSize.MENU),
             visible=True,
@@ -103,13 +112,17 @@ class TerminalNotebook(Gtk.Notebook):
         self.tab_selection_button.connect("clicked", self.on_tab_selection)
 
         self.action_box = Gtk.Box(visible=True)
+        self.action_box.pack_start(self.pin_button, 0, 0, 0)
         self.action_box.pack_start(self.new_page_button, 0, 0, 0)
-        self.action_box.pack_end(self.tab_selection_button, 0, 0, 0)
+        self.action_box.pack_start(self.tab_selection_button, 0, 0, 0)
         self.set_action_widget(self.action_box, Gtk.PackType.END)
 
     def attach_guake(self, guake):
         self.guake = guake
 
+        self.guake.settings.general.onChangedValue("window-losefocus", self.on_lose_focus_toggled)
+        self.pin_button.set_visible(self.guake.settings.general.get_boolean("window-losefocus"))
+
     def on_button_press(self, target, event, user_data):
         if event.button == 3:
             menu = mk_notebook_context_menu(self)
@@ -130,6 +143,16 @@ class TerminalNotebook(Gtk.Notebook):
 
         return False
 
+    def on_pin_clicked(self, user_data=None):
+        hide_prevention = HidePrevention(self.guake.window)
+        if self.pin_button.get_active():
+            hide_prevention.prevent()
+        else:
+            hide_prevention.allow()
+
+    def on_lose_focus_toggled(self, settings, key, user_data=None):
+        self.pin_button.set_visible(settings.get_boolean(key))
+
     @save_tabs_when_changed
     def on_new_tab(self, user_data):
         self.new_page_with_focus()
@@ -247,15 +270,15 @@ class TerminalNotebook(Gtk.Notebook):
             terminals += page.get_terminals()
         return terminals
 
-    def get_running_fg_processes_count(self):
-        fg_proc_count = 0
+    def get_running_fg_processes(self):
+        processes = []
         for page in self.iter_pages():
-            fg_proc_count += self.get_running_fg_processes_count_page(self.page_num(page))
-        return fg_proc_count
+            processes += self.get_running_fg_processes_page(page)
+        return processes
 
-    def get_running_fg_processes_count_page(self, index):
-        total_procs = 0
-        for terminal in self.get_terminals_for_page(index):
+    def get_running_fg_processes_page(self, page):
+        processes = []
+        for terminal in page.get_terminals():
             pty = terminal.get_pty()
             if not pty:
                 continue
@@ -265,14 +288,13 @@ class TerminalNotebook(Gtk.Notebook):
                 fgpid = posix.tcgetpgrp(fdpty)
                 log.debug("found running pid: %s", fgpid)
                 if fgpid not in (-1, term_pid):
-                    total_procs += 1
+                    processes.append((fgpid, get_process_name(fgpid)))
             except OSError:
                 log.debug(
                     "Cannot retrieve any pid from terminal %s, looks like it is already dead",
-                    index,
+                    terminal,
                 )
-                return 0
-        return total_procs
+        return processes
 
     def has_page(self):
         return self.get_n_pages() > 0
@@ -280,8 +302,7 @@ class TerminalNotebook(Gtk.Notebook):
     def iter_terminals(self):
         for page in self.iter_pages():
             if page is not None:
-                for t in page.iter_terminals():
-                    yield t
+                yield from page.iter_terminals()
 
     def iter_tabs(self):
         for page_num in range(self.get_n_pages()):
@@ -296,16 +317,17 @@ class TerminalNotebook(Gtk.Notebook):
         if page_num >= self.get_n_pages() or page_num < 0:
             log.error("Can not delete page %s no such index", page_num)
             return
+
+        page = self.get_nth_page(page_num)
         # TODO NOTEBOOK it would be nice if none of the "ui" stuff
         # (PromptQuitDialog) would be in here
-        procs = self.get_running_fg_processes_count_page(page_num)
-        if prompt == 2 or (prompt == 1 and procs > 0):
+        procs = self.get_running_fg_processes_page(page)
+        if prompt == PROMPT_ALWAYS or (prompt == PROMPT_PROCESSES and procs):
             # TODO NOTEBOOK remove call to guake
             if not PromptQuitDialog(self.guake.window, procs, -1, None).close_tab():
                 return
 
-        page = self.get_nth_page(page_num)
-        for terminal in self.get_terminals_for_page(page_num):
+        for terminal in page.get_terminals():
             if kill:
                 terminal.kill()
             terminal.destroy()
@@ -340,12 +362,12 @@ class TerminalNotebook(Gtk.Notebook):
     def delete_page_current(self, kill=True, prompt=0):
         self.delete_page(self.get_current_page(), kill, prompt)
 
-    def new_page(self, directory=None, position=None, empty=False):
+    def new_page(self, directory=None, position=None, empty=False, open_tab_cwd=False):
         terminal_box = TerminalBox()
         if empty:
             terminal = None
         else:
-            terminal = self.terminal_spawn(directory)
+            terminal = self.terminal_spawn(directory, open_tab_cwd)
             terminal_box.set_terminal(terminal)
         root_terminal_box = RootTerminalBox(self.guake, self)
         root_terminal_box.set_child(terminal_box)
@@ -379,7 +401,7 @@ class TerminalNotebook(Gtk.Notebook):
             else:
                 self.set_property("show-tabs", True)
 
-    def terminal_spawn(self, directory=None):
+    def terminal_spawn(self, directory=None, open_tab_cwd=False):
         terminal = GuakeTerminal(self.guake)
         terminal.grab_focus()
         terminal.connect(
@@ -389,7 +411,7 @@ class TerminalNotebook(Gtk.Notebook):
         if not isinstance(directory, str):
             directory = os.environ["HOME"]
             try:
-                if self.guake.settings.general.get_boolean("open-tab-cwd"):
+                if self.guake.settings.general.get_boolean("open-tab-cwd") or open_tab_cwd:
                     # Do last focused terminal still alive?
                     active_terminal = self.get_current_terminal()
                     if not active_terminal:
@@ -410,12 +432,20 @@ class TerminalNotebook(Gtk.Notebook):
         self.emit("terminal-spawned", terminal, terminal.pid)
 
     def new_page_with_focus(
-        self, directory=None, label=None, user_set=False, position=None, empty=False
+        self,
+        directory=None,
+        label=None,
+        user_set=False,
+        position=None,
+        empty=False,
+        open_tab_cwd=False,
     ):
-        box, page_num, terminal = self.new_page(directory, position=position, empty=empty)
+        box, page_num, terminal = self.new_page(
+            directory, position=position, empty=empty, open_tab_cwd=open_tab_cwd
+        )
         self.set_current_page(page_num)
         if not label:
-            self.rename_page(page_num, _("Terminal"), False)
+            self.rename_page(page_num, self.guake.compute_tab_title(terminal), False)
         else:
             self.rename_page(page_num, label, user_set)
         if terminal is not None:
@@ -511,7 +541,7 @@ class NotebookManager(GObject.Object):
             GObject.signal_new(
                 "notebook-created",
                 self,
-                GObject.SIGNAL_RUN_LAST,
+                GObject.SignalFlags.RUN_LAST,
                 GObject.TYPE_NONE,
                 (GObject.TYPE_PYOBJECT, GObject.TYPE_INT),
             )
@@ -582,8 +612,7 @@ class NotebookManager(GObject.Object):
 
     def iter_terminals(self):
         for k in self.notebooks:
-            for t in self.notebooks[k].iter_terminals():
-                yield t
+            yield from self.notebooks[k].iter_terminals()
 
     def get_terminal_by_uuid(self, terminal_uuid):
         for t in self.iter_terminals():
@@ -593,8 +622,7 @@ class NotebookManager(GObject.Object):
 
     def iter_pages(self):
         for k in self.notebooks:
-            for t in self.notebooks[k].iter_pages():
-                yield t
+            yield from self.notebooks[k].iter_pages()
 
     def iter_notebooks(self):
         for k in self.notebooks:
@@ -609,8 +637,8 @@ class NotebookManager(GObject.Object):
     def get_n_notebooks(self):
         return len(self.notebooks.keys())
 
-    def get_running_fg_processes_count(self):
-        r_fg_c = 0
+    def get_running_fg_processes(self):
+        processes = []
         for k in self.notebooks:
-            r_fg_c += self.notebooks[k].get_running_fg_processes_count()
-        return r_fg_c
+            processes += self.notebooks[k].get_running_fg_processes()
+        return processes
