@@ -45,6 +45,7 @@ from guake.globals import ALIGN_LEFT
 from guake.globals import ALIGN_RIGHT
 from guake.globals import ALIGN_TOP
 from guake.globals import ALWAYS_ON_PRIMARY
+from guake.globals import ENGINES
 from guake.globals import MAX_TRANSPARENCY
 from guake.globals import NAME
 from guake.globals import QUICK_OPEN_MATCHERS
@@ -103,6 +104,7 @@ HOTKEYS = [
         "keys": [
             {"key": "new-tab", "label": _("New tab")},
             {"key": "new-tab-home", "label": _("New tab in home directory")},
+            {"key": "new-tab-cwd", "label": _("New tab in current directory")},
             {"key": "close-tab", "label": _("Close tab")},
             {"key": "rename-current-tab", "label": _("Rename current tab")},
         ],
@@ -179,6 +181,7 @@ HOTKEYS = [
         "keys": [
             {"key": "clipboard-copy", "label": _("Copy text to clipboard")},
             {"key": "clipboard-paste", "label": _("Paste text from clipboard")},
+            {"key": "select-all", "label": _("Select all")},
         ],
     },
     {
@@ -230,7 +233,6 @@ def refresh_user_start(settings):
 
 
 class PrefsCallbacks:
-
     """Holds callbacks that will be used in the PrefsDialg class."""
 
     def __init__(self, prefDlg):
@@ -296,6 +298,24 @@ class PrefsCallbacks:
         """Set the `prompt_on_close_tab' property in dconf"""
         self.settings.general.set_int("prompt-on-close-tab", combo.get_active())
 
+    def on_search_engine_changed(self, combo):
+        """
+        Sets the 'search-engine' value in dnonf.
+        Also controls the editability of 'custom_search' input
+        """
+        custom_search = self.prefDlg.get_widget("custom_search")
+        # if 'Custom' is selected make the search engine input editable
+        if combo.get_active() not in ENGINES:
+            custom_search.set_sensitive(True)
+        else:
+            # make read-only
+            custom_search.set_sensitive(False)
+        self.settings.general.set_int("search-engine", combo.get_active())
+
+    def on_custom_search_changed(self, edt):
+        """Sets the 'custom-search-engine' property in dconf"""
+        self.settings.general.set_string("custom-search-engine", edt.get_text())
+
     def on_gtk_theme_name_changed(self, combo):
         """Set the `gtk_theme_name' property in dconf"""
         citer = combo.get_active_iter()
@@ -515,8 +535,19 @@ class PrefsCallbacks:
         self.settings.styleFont.set_string("style", fbtn.get_font_name())
 
     def on_background_image_file_chooser_file_changed(self, fc):
+        allowed_extensions = (
+            ".jpg",
+            ".jpeg",
+            ".png",
+            ".gif",
+        )  # only allow files with these extensions
         self.settings.general.set_string(
-            "background-image-file", fc.get_filename() if fc.get_filename() else ""
+            "background-image-file",
+            (
+                fc.get_filename()
+                if fc.get_filename() and fc.get_filename().endswith(allowed_extensions)
+                else ""
+            ),
         )
 
     def on_background_image_file_remove_clicked(self, btn):
@@ -610,7 +641,6 @@ class PrefsCallbacks:
 
 
 class PrefsDialog(SimpleGladeApp):
-
     """The Guake Preferences dialog."""
 
     def __init__(self, settings):
@@ -1045,6 +1075,18 @@ class PrefsDialog(SimpleGladeApp):
         self.get_widget("prompt_on_close_tab").set_active(value)
         self.get_widget("prompt_on_quit").set_sensitive(value != 2)
 
+        # search engine
+        value = self.settings.general.get_int("search-engine")
+        custom_search = self.get_widget("custom_search")
+        custom_search.set_text(self.settings.general.get_string("custom-search-engine"))
+        self.get_widget("search_engine_select").set_active(value)
+        # if 'Custom' is selected make the search engine input editable
+        if value not in ENGINES:
+            # make read-only
+            custom_search.set_sensitive(True)
+        else:
+            custom_search.set_sensitive(False)
+
         # use system theme
         value = self.settings.general.get_boolean("gtk-use-system-default-theme")
         self.get_widget("gtk_use_system_default_theme").set_active(value)
@@ -1133,6 +1175,10 @@ class PrefsDialog(SimpleGladeApp):
         value = self.settings.general.get_boolean("fullscreen-hide-tabbar")
         self.get_widget("fullscreen_hide_tabbar").set_active(value)
 
+        # new tabs appear after current tab
+        value = self.settings.general.get_boolean("new-tab-after")
+        self.get_widget("new_tab_after").set_active(value)
+
         # hide tabbar if only one tab
         value = self.settings.general.get_boolean("hide-tabs-if-one-tab")
         self.get_widget("hide_tabs_if_one_tab").set_active(value)
