@@ -94,14 +94,16 @@ class DropTargets(IntEnum):
 
 
 class GuakeTerminal(Vte.Terminal):
-
     """Just a vte.Terminal with some properties already set."""
 
     def __init__(self, guake):
         super().__init__()
         self.guake = guake
         self.configure_terminal()
-        self.add_matches()
+
+        if self.guake.settings.general.get_boolean("quick-open-enable"):
+            self.add_matches()
+
         self.handler_ids = []
         self.handler_ids.append(self.connect("button-press-event", self.button_press))
         self.connect("child-exited", self.on_child_exited)  # Call on_child_exited, don't remove it
@@ -347,13 +349,17 @@ class GuakeTerminal(Vte.Terminal):
         handle the matched resource uri.
         """
         self.matched_value = ""
-        if (Vte.MAJOR_VERSION, Vte.MINOR_VERSION) >= (0, 46):
-            matched_string = self.match_check_event(event)
+
+        if self.guake.settings.general.get_boolean("quick-open-enable"):
+            if (Vte.MAJOR_VERSION, Vte.MINOR_VERSION) >= (0, 46):
+                matched_string = self.match_check_event(event)
+            else:
+                matched_string = self.match_check(
+                    int(event.x / self.get_char_width()),
+                    int(event.y / self.get_char_height()),
+                )
         else:
-            matched_string = self.match_check(
-                int(event.x / self.get_char_width()),
-                int(event.y / self.get_char_height()),
-            )
+            matched_string = None
 
         self.found_link = None
 
@@ -366,7 +372,7 @@ class GuakeTerminal(Vte.Terminal):
                 self._on_ctrl_click_matcher((s, None))
             elif self.get_has_selection():
                 self.quick_open()
-            elif matched_string and matched_string[0]:
+            elif matched_string is not None and matched_string[0]:
                 self._on_ctrl_click_matcher(matched_string)
         elif event.button == 3 and matched_string:
             self.found_link = self.handleTerminalMatch(matched_string)
@@ -650,9 +656,11 @@ class GuakeTerminal(Vte.Terminal):
         return {
             "fg_color": self._color_to_list(self.custom_fgcolor),
             "bg_color": self._color_to_list(self.custom_bgcolor),
-            "palette": [self._color_to_list(col) for col in self.custom_palette]
-            if self.custom_palette
-            else None,
+            "palette": (
+                [self._color_to_list(col) for col in self.custom_palette]
+                if self.custom_palette
+                else None
+            ),
         }
 
     def set_custom_colors_from_dict(self, colors_dict):
