@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=redefined-outer-name
+import os
 
 from guake.utils import FileManager
+from guake.utils import get_process_name
 
 
 def test_file_manager(fs):
@@ -37,3 +39,7 @@ def test_file_manager_clear(fs):
     assert fm.read("/foo/bar") == "test"
     fm.clear()
     assert fm.read("/foo/bar") == "changed"
+
+
+def test_process_name():
+    assert get_process_name(os.getpid())
